vip\_hci.metrics package
========================

Submodules
----------

vip\_hci.metrics.completeness module
------------------------------------

.. automodule:: vip_hci.metrics.completeness
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.metrics.contrcurve module
----------------------------------

.. automodule:: vip_hci.metrics.contrcurve
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.metrics.detection module
---------------------------------

.. automodule:: vip_hci.metrics.detection
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.metrics.roc module
---------------------------

.. automodule:: vip_hci.metrics.roc
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.metrics.snr\_source module
-----------------------------------

.. automodule:: vip_hci.metrics.snr_source
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.metrics.stim module
----------------------------

.. automodule:: vip_hci.metrics.stim
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: vip_hci.metrics
   :members:
   :undoc-members:
   :show-inheritance:
